@@ -4,6 +4,7 @@ use solana_core::validator::ValidatorConfig;
 use solana_gossip::{cluster_info::Node, contact_info::ContactInfo};
 use solana_sdk::pubkey::Pubkey;
 use solana_sdk::signature::Keypair;
+use solana_streamer::socket::SocketAddrSpace;
 use std::path::PathBuf;
 use std::sync::Arc;
 
@@ -39,7 +40,12 @@ pub trait Cluster {
     fn get_validator_client(&self, pubkey: &Pubkey) -> Option<ThinClient>;
     fn get_contact_info(&self, pubkey: &Pubkey) -> Option<&ContactInfo>;
     fn exit_node(&mut self, pubkey: &Pubkey) -> ClusterValidatorInfo;
-    fn restart_node(&mut self, pubkey: &Pubkey, cluster_validator_info: ClusterValidatorInfo);
+    fn restart_node(
+        &mut self,
+        pubkey: &Pubkey,
+        cluster_validator_info: ClusterValidatorInfo,
+        socket_addr_space: SocketAddrSpace,
+    );
     fn create_restart_context(
         &mut self,
         pubkey: &Pubkey,
@@ -48,7 +54,13 @@ pub trait Cluster {
     fn restart_node_with_context(
         cluster_validator_info: ClusterValidatorInfo,
         restart_context: (Node, Option<ContactInfo>),
+        socket_addr_space: SocketAddrSpace,
     ) -> ClusterValidatorInfo;
     fn add_node(&mut self, pubkey: &Pubkey, cluster_validator_info: ClusterValidatorInfo);
-    fn exit_restart_node(&mut self, pubkey: &Pubkey, config: ValidatorConfig);
+    fn exit_restart_node(
+        &mut self,
+        pubkey: &Pubkey,
+        config: ValidatorConfig,
+        socket_addr_space: SocketAddrSpace,
+    );
 }
